
<img width=400 src="https://gitlab.com/tkog/pydecs/-/wikis/uploads/5b35536e5f63e1433affda74549140e2/pydecs_logo.jpg">

### PYthon code for point-like Defect Equilibria in Crystalline Solids
---

# Check:  [User manual](https://gitlab.com/tkog/pydecs/-/wikis/home)



#### Reference: [T. Ogawa, A. Taguchi, and A. Kuwabara, "An extended computational approach for point-defect equilibria in semiconductor materials", npj Comput. Mater. 8, 79 (2022).](https://doi.org/10.1038/s41524-022-00756-0)  
---
#### This module is licensed under the Apache License, Version 2.0, see LICENSE.txt.
---
